@@ -3,7 +3,6 @@
 import os
 import re
 import platform
-import warnings
 import subprocess
 import logger
 try:
@@ -24,30 +23,30 @@ class Simpanadefaults():
         """
         Method to read Windows Registry
         """
-        keyvalue = None
+        key_value = None
         status = False
         try:
             key2 = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE,
                                   path, 0, winreg.KEY_ALL_ACCESS)
-            keylist = winreg.QueryValueEx(key2, keyname)
-            keyvalue = keylist[0]
+            key_list = winreg.QueryValueEx(key2, keyname)
+            key_value = key_list[0]
             status = True
-        except Exception as windows_registry_exception:
+        except Exception:
             status = False
         finally:
-            return(status, keyvalue)
+            return status, key_value
 
     def local_cs_detection(self, instance_name):
-        loglines = []
         """
-		Method to detect local commvault  installation and
-		returns the local  CS name  to the calling function
-		Args :
-		instance_name:Commvault Instance
-		Returns :
-		status = True | False depending on Simpana Detection on Local Machine
-		csName= Simpana CS for the currently detected Local client
-		"""
+        Method to detect local commvault  installation and
+        returns the local  CS name  to the calling function
+        Args :
+        instance_name:Commvault Instance
+        Returns :
+        status = True | False depending on Commvault Detection on Local Machine
+        csName= Commvault CS for the currently detected Local client
+        """
+        loglines = []
         try:
             csname = ""
             flag = False
@@ -81,7 +80,7 @@ class Simpanadefaults():
                         home_string = home.decode().rstrip('\n')
                         cv_reg_path = "CommVaultRegistry/Galaxy/"
                         cv_reg_path = os.path.join(home_string, cv_reg_path)
-                        if(os.path.exists(cv_reg_path)):
+                        if os.path.exists(cv_reg_path):
                             reg_path = cv_reg_path
                     linux_path1 = reg_path + instance_name
                     if os.path.exists(linux_path1):
@@ -127,16 +126,16 @@ class Simpanadefaults():
             return (flag, csname, loglines)
 
     def local_client_detection(self, instance_name):
-        loglines = []
         """
-		Method to detect local commvault installation  and
-		returns the local client name to the calling function
-		Args :
-		instance_name:Commvault Instance
-		Returns :
-		status = True | False depending on Commvault Detection on Local Machine
-		clientName=Local Simpana Client Name
-		"""
+        Method to detect local commvault installation  and
+        returns the local client name to the calling function
+        Args :
+        instance_name:Commvault Instance
+        Returns :
+        status = True | False depending on Commvault Detection on Local Machine
+        clientName=Local client name
+        """
+        loglines = []
         try:
             clientname = ""
             flag = False
@@ -167,7 +166,7 @@ class Simpanadefaults():
                         home_string = home.decode().rstrip('\n')
                         cv_reg_path = "CommVaultRegistry/Galaxy/"
                         cv_reg_path = os.path.join(home_string, cv_reg_path)
-                        if(os.path.exists(cv_reg_path)):
+                        if os.path.exists(cv_reg_path):
                             reg_path = cv_reg_path
                     linux_path1 = reg_path + instance_name
                     if os.path.exists(linux_path1):
@@ -206,14 +205,14 @@ class Simpanadefaults():
             return (flag, clientname, loglines)
 
     def check_for_local_instance(self, client_name):
-        loglines = []
         """
-		Method to detect if client passed belongs to local instance
-		Args :
-		client_name:Client Name
-		Returns :
-		status = True | False depending on whether client is local
-		"""
+        Method to detect if client passed belongs to local instance
+        Args :
+        client_name:Client Name
+        Returns :
+        status = True | False depending on whether client is local
+        """
+        loglines = []
         try:
             flag = False
 
@@ -231,9 +230,9 @@ class Simpanadefaults():
                             i = i + 1
                         except WindowsError:
                             break
-                    for p in instances_list:
-                        if p.startswith("Instance"):
-                            instance_path = 'SOFTWARE\\CommVault Systems\\Galaxy' + "\\" + p
+                    for path in instances_list:
+                        if path.startswith("Instance"):
+                            instance_path = 'SOFTWARE\\CommVault Systems\\Galaxy' + "\\" + path
                             keyname = 'sPhysicalNodeName'
                             (status, clientname) = Simpanadefaults(
                             )._winregistry_reading(instance_path, keyname)
@@ -245,7 +244,7 @@ class Simpanadefaults():
                     windows_registry_exception = str(
                         windows_registry_exception)
                     flag = False
-                    loglines.append(["e", "Exception in accessing Windows Simpana Registry :%s" %
+                    loglines.append(["e", "Exception in accessing Windows Commvault Registry :%s" %
                                      windows_registry_exception])
 
             elif platform.system() == 'Linux':
@@ -265,7 +264,7 @@ class Simpanadefaults():
                         home_string = home.decode().rstrip('\n')
                         cv_reg_path = "CommVaultRegistry/Galaxy/"
                         cv_reg_path = os.path.join(home_string, cv_reg_path)
-                        if(os.path.exists(cv_reg_path)):
+                        if os.path.exists(cv_reg_path):
                             reg_path = cv_reg_path
                     if os.path.exists(reg_path):
                         instances_list = None
@@ -332,7 +331,7 @@ class Simpanadefaults():
                     windows_registry_exception = str(
                         windows_registry_exception)
                     flag = False
-                    loglines.append(["e", "Exception in accessing Windows Simpana Registry :%s" %
+                    loglines.append(["e", "Exception in accessing Windows Commvault Registry :%s" %
                                      windows_registry_exception])
 
             elif platform.system() == 'Linux':
@@ -352,7 +351,7 @@ class Simpanadefaults():
                         home_string = home.decode().rstrip('\n')
                         cv_reg_path = "CommVaultRegistry/Galaxy/"
                         cv_reg_path = os.path.join(home_string, cv_reg_path)
-                        if(os.path.exists(cv_reg_path)):
+                        if os.path.exists(cv_reg_path):
                             reg_path = cv_reg_path
                     linux_path1 = reg_path + instance_name + "/Base"
                     if os.path.exists(linux_path1):
@@ -385,7 +384,7 @@ class Simpanadefaults():
                 loglines.append(["e", "Unsupported OS"])
                 # sys.exit(0)
         except Exception as simpana_detect_exception:
-            loglines.append(["e", "Exception in simpana installation path detection : %s" %
+            loglines.append(["e", "Exception in Commvault installation path detection : %s" %
                              simpana_detect_exception])
 
         finally:
@@ -413,7 +412,7 @@ class Simpanadefaults():
                     windows_registry_exception = str(
                         windows_registry_exception)
                     flag = False
-                    loglines.append(["e", "Exception in accessing Windows Simpana Registry :%s" %
+                    loglines.append(["e", "Exception in accessing Windows Commvault Registry :%s" %
                                      windows_registry_exception])
 
             elif platform.system() == 'Linux':
@@ -433,7 +432,7 @@ class Simpanadefaults():
                         home_string = home.decode().rstrip('\n')
                         cv_reg_path = "CommVaultRegistry/Galaxy/"
                         cv_reg_path = os.path.join(home_string, cv_reg_path)
-                        if(os.path.exists(cv_reg_path)):
+                        if os.path.exists(cv_reg_path):
                             reg_path = cv_reg_path
                     linux_path1 = reg_path + instance_name + "/EventManager"
                     if os.path.exists(linux_path1):
@@ -466,21 +465,21 @@ class Simpanadefaults():
                 loglines.append(["e", "Unsupported OS"])
                 # sys.exit(0)
         except Exception as simpana_detect_exception:
-            loglines.append(["e", "Exception in simpana logging path detection : %s" %
+            loglines.append(["e", "Exception in Commvault logging path detection : %s" %
                              simpana_detect_exception])
 
         finally:
             return (flag, logging_path, loglines)
 
     def check_valid_instance(self, instance_name):
-        loglines = []
         """
-		Method to detect if instance passed is a valid instance
-		Args :
-		instance_name:instance Name
-		Returns :
-		status = True | False depending on whether instance is valid
-		"""
+        Method to detect if instance passed is a valid instance
+        Args :
+        instance_name:instance Name
+        Returns :
+        status = True | False depending on whether instance is valid
+        """
+        loglines = []
         loglines.append(["i", "Checking validity of instance name"])
         try:
             flag = False
@@ -508,7 +507,7 @@ class Simpanadefaults():
                     windows_registry_exception = str(
                         windows_registry_exception)
                     flag = False
-                    loglines.append(["e", "Exception in accessing Windows Simpana Registry :%s" %
+                    loglines.append(["e", "Exception in accessing Windows Commvault Registry :%s" %
                                      windows_registry_exception])
 
             elif platform.system() == 'Linux':
@@ -528,7 +527,7 @@ class Simpanadefaults():
                         home_string = home.decode().rstrip('\n')
                         cv_reg_path = "CommVaultRegistry/Galaxy/"
                         cv_reg_path = os.path.join(home_string, cv_reg_path)
-                        if(os.path.exists(cv_reg_path)):
+                        if os.path.exists(cv_reg_path):
                             reg_path = cv_reg_path
                     if os.path.exists(reg_path):
                         instances_list = None
@@ -584,3 +583,83 @@ class Simpanadefaults():
                 return content.strip()
 
         return "Instance001"
+
+    def allow_http(self, instance, log):
+        """
+        Checks for registry key value of bAllowCVCHttpFallback
+
+        Args:
+
+            instance    (str)   --  Instance name like Instance001
+
+            log         (obj)   --  Logger class object
+
+        Returns:
+
+            (bool)  -   True if bAllowCVCHttpFallback is set True else false
+
+        """
+        log.info("Checking registry value for key bAllowCVCHttpFallback")
+        value = None
+        try:
+            if platform.system() == 'Windows':
+                reg_path = rf'SOFTWARE\CommVault Systems\Galaxy\{instance}\EventManager'
+                _, value = self._winregistry_reading(reg_path, 'bAllowCVCHttpFallback')
+
+            elif platform.system() == 'Linux':
+                value = self._get_unix_registry(instance, 'EventManager', 'bAllowCVCHttpFallback')
+
+        except Exception:
+            log.info("Unable to fetch registry value for bAllowCVCHttpFallback")
+
+        finally:
+            if value:
+                return True
+            return False
+
+    def _get_unix_registry(self, instance, category, key_name):
+        """
+        Reads the registry value from the given path
+
+        Args:
+            instance    (str)   --  Instance name like Instance001
+
+            category    (str)   -- Category the key belongs to
+                                    Example: EventManager
+
+            key_name    (str)   -- Registry key name
+
+        """
+        value = None
+        cmd = subprocess.Popen("id -u", stdout=subprocess.PIPE, shell=True)
+        user_id, _ = cmd.communicate()
+        user_id = int(user_id)
+        reg_path = "/etc/CommVaultRegistry/Galaxy"
+        if user_id != 0:
+            home_cmd = subprocess.Popen("echo $HOME", stdout=subprocess.PIPE, shell=True)
+            home_path, _ = home_cmd.communicate()
+            home_path = home_path.decode().rstrip('\n')
+            temp_reg_path = f"{home_path}/CommVaultRegistry/Galaxy"
+
+            if os.path.exists(temp_reg_path):
+                reg_path = temp_reg_path
+
+        reg_path = f"{reg_path}/{instance}/{category}/.properties"
+
+        if not os.access(reg_path, 4):
+            return ''
+        if os.path.exists(reg_path):
+            with open(reg_path, 'r') as rfile:
+                content = rfile.readlines()
+
+            for line in content:
+                if line.startswith(key_name):
+                    value = line.split(' ')[1]
+                    try:
+                        value = int(value)
+                    except Exception:
+                        pass
+
+                    break
+
+        return value
