@@ -61,6 +61,8 @@ FSBackupset:
 
     create_granular_replica_copy()      --   Triggers  Granular replication permanent mount
 
+    get_browse_volume_guid()             --   It returns browse volume guid
+
 """
 
 from __future__ import unicode_literals
@@ -1067,8 +1069,8 @@ class FSBackupset(Backupset):
             raise SDKException('Backupset', '105')
 
 
-
-    def create_replica_copy(self, srcclientid, destclientid, scid, blrid, srcguid, dstguid, **replication_options):
+    def create_replica_copy(self, srcclientid, destclientid, scid, blrid,
+                            srcguid, dstguid, **replication_options):
 
         """"setter for live  blklvl Replication replica copy...
 
@@ -1081,13 +1083,14 @@ class FSBackupset(Backupset):
 
             blrid           (int) -- Blr pair id
 
+            srcguid         (str) -- Browse guid of source
+
+            dstguid          (str) -- Browse guid of destination volume
+
             **replication_options (dict) -- object instance
 
 
         """
-
-
-
         srcvol = replication_options.get('srcvol')
         restorepath = replication_options.get('RestorePath')
         replicacopyjson = {
@@ -1134,8 +1137,8 @@ class FSBackupset(Backupset):
                                                     {
                                                         "mountPath": restorepath,
                                                         "srcPath": srcvol,
-                                                        "srcGuid": dstguid,
-                                                        "dstGuid": srcguid
+                                                        "srcGuid": srcguid,
+                                                        "dstGuid": dstguid
                                                     }
                                                 ]
                                             }
@@ -1152,7 +1155,8 @@ class FSBackupset(Backupset):
             }
         }
 
-        flag, response = self._cvpysdk_object.make_request('POST', self._services['RESTORE'], replicacopyjson)
+        flag, response = self._cvpysdk_object.make_request('POST', self._services['RESTORE'],
+                                                           replicacopyjson)
         if flag:
             if response.json():
                 if "jobIds" in response.json():
@@ -1175,28 +1179,31 @@ class FSBackupset(Backupset):
 
 
     def delete_replication_pair(self, blrid):
-
         """"Delete replication pair
-
         Args:
             blrid   (int)  --  blocklevel replication id.
-
-
         """
-
         flag, response = self._cvpysdk_object.make_request('DELETE', self._services['DELETE_BLR_PAIR']%blrid)
 
         if response.status_code != 200 and flag == False:
             raise SDKException('Response', '101', self._update_response_(response.text))
 
-    def create_fsblr_replication_pair(self, srcclientid, destclientid, rpstoreid=None, replicationtype=None,
-                                      **replication_options):
+    def create_fsblr_replication_pair(self, srcclientid, destclientid, srcguid, destguid,
+                                      rpstoreid=None, replicationtype=None, **replication_options):
         """"Create granular replication pair  json
 
         Args:
             srcclientid   (int)  --  Source client id.
 
-            destclientid    (dict)  -- Destintion client id .
+            destclientid   (dict)  -- Destintion client id .
+
+            srcguid        (str) -- Browse guid of source
+
+            dstguid        (str) -- Browse guid of destination volume
+
+            rpstoreid      (str) -- Rp store id for replication
+
+            replicationtype (str) -- Replication pair  type to create
 
             **replication_options (dict) -- object instance
 
@@ -1221,9 +1228,9 @@ class FSBackupset(Backupset):
             "srcEndPointType": 2,
             "srcDestVolumeMap": [
                 {
-                    "sourceVolumeGUID": "55053f38-2de9-429c-945a-bb8827911c11",
+                    "sourceVolumeGUID": srcguid,
                     "destVolume": destvol,
-                    "destVolumeGUID": "3758a646-7b30-411b-88ea-12f6b957dfd1",
+                    "destVolumeGUID": destguid,
                     "sourceVolume": srcvol
                 }
             ],
@@ -1241,8 +1248,15 @@ class FSBackupset(Backupset):
             }
         }
         flag, response = self._cvpysdk_object.make_request('POST', self._services['CREATE_BLR_PAIR'], granularjson)
-        if response.status_code != 200 and flag == False:
-            raise SDKException('Response', '101', self._update_response_(response.text))
+
+        if flag:
+            if response and response.json():
+                if response.json().get('errorCode', 0) != 0:
+                    raise SDKException('Response', '101', self._update_response_(response.text))
+            else:
+                raise SDKException('Response', '102')
+        else:
+            raise SDKException('Response', '101')
 
 
 
@@ -1259,8 +1273,12 @@ class FSBackupset(Backupset):
 
             blrid           (int) -- Blr pair id
 
+            srcguid         (str) -- source volume guid
+
             dstguid         (str) -- Destination relication guid
 
+            restoreguid     (str) -- RP store guid
+
             timestamp        (int) -- Replication point timestamp
 
             **replication_options (dict) -- object instance
@@ -1271,7 +1289,7 @@ class FSBackupset(Backupset):
         import re
 
         flag, response = self._cvpysdk_object.make_request('GET', self._services['GRANULAR_BLR_POINTS']
-                                                           %(destclientid, scid, dstguid))
+                                                           %(destclientid, scid, srcguid))
         replicapoints = response.content
         temp = replicapoints.split(b"},")
         list_rp = temp[len(temp) - 1]
@@ -1328,8 +1346,8 @@ class FSBackupset(Backupset):
                                                     {
                                                         "mountPath": restorepath,
                                                         "srcPath": srcvol,
-                                                        "srcGuid": restoreguid,
-                                                        "dstGuid": srcguid
+                                                        "srcGuid": dstguid,
+                                                        "dstGuid": restoreguid
                                                     }
                                                 ],
                                                 "rp": {
@@ -1353,11 +1371,8 @@ class FSBackupset(Backupset):
             }
         }
 
-
-
         flag, response = self._cvpysdk_object.make_request('POST', self._services['RESTORE'], replicacopyjson)
 
-
         if flag:
             if response.json():
                 if "jobIds" in response.json():
@@ -1377,3 +1392,26 @@ class FSBackupset(Backupset):
                 raise SDKException('Response', '102')
         else:
             raise SDKException('Response', '101', self._update_response_(response.text))
+
+
+    def get_browse_volume_guid(self):
+
+        """"to get browse volume guids for client
+            Returns:
+                vguids (json) : Returns volume guids and properties
+
+        """
+        client_id= self._client_object.client_id
+        flag, response = self._cvpysdk_object.make_request('GET', self._services['BROWSE_MOUNT_POINTS']
+                                                           %(client_id))
+        if flag:
+            if response and response.json():
+                vguids = response.json()
+                if response.json().get('errorCode', 0) != 0:
+                    raise SDKException('Response', '101', self._update_response_(response.text))
+            else:
+                raise SDKException('Response', '102')
+        else:
+            raise SDKException('Response', '101')
+
+        return vguids
\ No newline at end of file
